function [L,r,Rx,Ry,Vx,Vy] = ...
                         LIGGGHTSinit_fromdump(atomdata,params,parbnd,outfile)
% LIGGGHTSinit_fromdump - writes an input file for LAMMPS/LIGGGHTS 
%                         based on data read from a dump file
%
% Author: Agnieszka Herman, IOUG (agnieszka.herman@ug.edu.pl)
%
N  = length(atomdata.r);
r = atomdata.r;
Lx = atomdata.L(1);
Ly = atomdata.L(2);
L  = [Lx Ly];
Rx = atomdata.x;
Ry = atomdata.y;
if params.Vwrite > 0
    Vx = atomdata.vx;
    Vy = atomdata.vy;
    omegax = atomdata.omegax;
    omegay = atomdata.omegay;
    omegaz = atomdata.omegaz;
else
    Vx = [];
    Vy = [];
end
%========================================================================
%=== Initialize bonds:
%========================================================================
if parbnd.ibnd == 2
    bondlist = [];
    nextra = 0;
    for ii = 1:N-1
        ipartner = ii+1:N;
        RXIJ = Rx(ii) - Rx(ipartner);
        RYIJ = Ry(ii) - Ry(ipartner);
        % bonds are not created around a periodic boundary:
        dist = sqrt(RXIJ.^2 + RYIJ.^2) - (r(ii)+r(ipartner));
        ind = find(dist <= parbnd.dmax);
        nextra = max(nextra,length(ind));
        ibnd = [ii*ones(length(ind),1) ipartner(ind)'];
        bondlist = [bondlist; ibnd];
    end
    if parbnd.bondstoremove > 0
        if parbnd.bondstoremove > 1
            error('parbnd.bondstoremove must be lower than 1');
        else
            ind = randperm(size(bondlist,1),round(parbnd.bondstoremove*size(bondlist,1)));
            bondlist(ind,:) = [];
        end
    end
    if parbnd.nbondtypes>1
        Nb = size(bondlist,1);
        bondtype = zeros(Nb,1);
        nbtot = 0;
        for ii = 1:parbnd.nbondtypes-1
            nbt = round(Nb*parbnd.bondtyperatio(ii));
            bondtype(nbtot+1:nbtot+nbt) = ii;
            nbtot = nbtot + nbt;
        end
        bondtype(nbtot+1:end) = parbnd.nbondtypes;
        bondtype = bondtype(randperm(Nb));
    else
        Nb = size(bondlist,1);
        bondtype = ones(Nb,1);
    end
end
%========================================================================
%=== Write the LIGGGHTS input file(s):
%========================================================================
if parbnd.ibnd == 0
    fid = fopen(outfile,'w');
    fprintf(fid,'%s\n\n',' Input file for LIGGGHTS, created with Matlab function LIGGGHTSinit_fromdump.m');
    fprintf(fid,'%5.0f%s\n\n',N,' atoms');
    fprintf(fid,'%5.0f%s\n\n',1,' atom types');
    fprintf(fid,'%15.3f%15.3f%s\n',-Lx/2,Lx/2,' xlo xhi');
    fprintf(fid,'%15.3f%15.3f%s\n',-Ly/2,Ly/2,' ylo yhi');
    fprintf(fid,'%15.3f%15.3f%s\n\n',-0.5,0.5,' zlo zhi');
    fprintf(fid,'%s\n\n',' Atoms');
    for n = 1:N
        fprintf(fid,'%6.0f%2.0f%12.3f%9.3f%9.3f%15.3f%15.3f%15.3f\n', ...
                             n,1,2*r(n),params.h,params.rho,Rx(n),Ry(n),0);
    end
    if params.Vwrite > 0
        fprintf(fid,'\n%s\n\n',' Velocities');
        for n = 1:N
            fprintf(fid,'%6.0f%9.3f%9.3f%9.3f%12.5f%12.5f%12.5f\n',n,Vx(n),Vy(n),0,omegax(n),omegay(n),omegaz(n));
        end
    end
    fclose(fid);
elseif parbnd.ibnd == 1
    fid = fopen(outfile,'w');
    fprintf(fid,'%s\n\n',' Input file for LIGGGHTS, created with Matlab function LIGGGHTSinit_fromdump.m');
    fprintf(fid,'%5.0f%s\n\n',N,' atoms');
    fprintf(fid,'%5.0f%s\n\n',1,' atom types');
    fprintf(fid,'%15.3f%15.3f%s\n',-Lx/2,Lx/2,' xlo xhi');
    fprintf(fid,'%15.3f%15.3f%s\n',-Ly/2,Ly/2,' ylo yhi');
    fprintf(fid,'%15.3f%15.3f%s\n\n',-0.5,0.5,' zlo zhi');
    fprintf(fid,'%5.0f%s\n\n',0,' bonds');    
    fprintf(fid,'%5.0f%s\n\n',parbnd.nbondtypes,' bond types');    
    fprintf(fid,'%5.0f%s\n\n',parbnd.nextra,' extra bond per atom');    
    fprintf(fid,'%s\n\n',' Atoms');
    for n = 1:N
        fprintf(fid,'%6.0f%2.0f%15.3f%15.3f%15.3f%12.3f%9.3f%9.3f%2.0f\n', ...
                             n,1,Rx(n),Ry(n),0,2*r(n),params.h,params.rho,1);
    end
    if params.Vwrite > 0
        fprintf(fid,'\n%s\n\n',' Velocities');
        for n = 1:N
            fprintf(fid,'%6.0f%9.3f%9.3f%9.3f%12.5f%12.5f%12.5f\n',n,Vx(n),Vy(n),0,omegax(n),omegay(n),omegaz(n));
        end
    end
    fclose(fid);
elseif parbnd.ibnd == 2
    fid = fopen(outfile,'w');
    fprintf(fid,'%s\n\n',' Input file for LIGGGHTS, created with Matlab function LIGGGHTSinit_fromdump.m');
    fprintf(fid,'%5.0f%s\n\n',N,' atoms');
    fprintf(fid,'%5.0f%s\n\n',1,' atom types');
    fprintf(fid,'%15.3f%15.3f%s\n',-Lx/2,Lx/2,' xlo xhi');
    fprintf(fid,'%15.3f%15.3f%s\n',-Ly/2,Ly/2,' ylo yhi');
    fprintf(fid,'%15.3f%15.3f%s\n\n',-0.5,0.5,' zlo zhi');
    fprintf(fid,'%5.0f%s\n\n',size(bondlist,1),' bonds');    
    fprintf(fid,'%5.0f%s\n\n',parbnd.nbondtypes,' bond types');    
    fprintf(fid,'%5.0f%s\n\n',max(parbnd.nextra,nextra),' extra bond per atom');    
    fprintf(fid,'%s\n\n',' Atoms');
    for n = 1:N
        fprintf(fid,'%6.0f%2.0f%15.3f%15.3f%15.3f%12.3f%9.3f%9.3f%2.0f\n', ...
                             n,1,Rx(n),Ry(n),0,2*r(n),params.h,params.rho,1);
    end
    if params.Vwrite > 0
        fprintf(fid,'\n%s\n\n',' Velocities');
        for n = 1:N
            fprintf(fid,'%6.0f%9.3f%9.3f%9.3f%12.5f%12.5f%12.5f\n',n,Vx(n),Vy(n),0,omegax(n),omegay(n),omegaz(n));
        end
    end
    fprintf(fid,'\n%s\n\n',' Bonds');
    for n = 1:size(bondlist,1)
        fprintf(fid,'%8.0f%3.0f%8.0f%8.0f\n',n,bondtype(n),bondlist(n,1),bondlist(n,2));
    end
    fclose(fid);    
end