function [bnd,S] = floeshape(atomdata,F,Fno)
% floeshape -- determines the outer boundary of a group of grains building a floe. 
%
% Author: Agnieszka Herman, IOUG (agnieszka.herman@ug.edu.pl)
%
nf = max(F);             % no. of floes
th = linspace(0,2*pi,50);
dth = 2*pi/50/3;
S = zeros(nf,1);
for n = 1:nf
    %disp(n);
    x = atomdata.x(F==n);
    y = atomdata.y(F==n);
    r = atomdata.r(F==n);
    xp = repmat(x,1,length(th))+ ...
          repmat(r,1,length(th)).*repmat(cos(th),length(r),1);
    yp = repmat(y,1,length(th))+ ...
          repmat(r,1,length(th)).*repmat(sin(th),length(r),1);    
    if Fno(n)>1
        xp2 = repmat(x,1,length(th))+ ...
              repmat(r/3,1,length(th)).*repmat(cos(th+dth),length(r),1);
        yp2 = repmat(y,1,length(th))+ ...
              repmat(r/3,1,length(th)).*repmat(sin(th+dth),length(r),1);
        xp3 = repmat(x,1,length(th))+ ...
              repmat(2*r/3,1,length(th)).*repmat(cos(th-dth),length(r),1);
        yp3 = repmat(y,1,length(th))+ ...
              repmat(2*r/3,1,length(th)).*repmat(sin(th-dth),length(r),1);
        xp = [xp(:); xp2(:); xp3(:)];
        yp = [yp(:); yp2(:); yp3(:)];
        % version 1:
        [k,S(n)] = boundary(xp,yp,.6); 
        bnd{n} = [xp(k) yp(k)];            
    else
        bnd{n} = [xp(:) yp(:)];
        S(n) = pi*r^2;
    end

end
